@@ -1,5 +1,5 @@
 /* gpe-sketchbook -- a sketches notebook program for PDA
- * Copyright (C) 2002 Luc Pionchon
+ * Copyright (C) 2002, 2003, 2004, 2005 Luc Pionchon
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,30 +23,43 @@
 #define THUMBNAIL_SIZE 64
 
 typedef struct _selector {
-  GtkWidget * iconlist;//top level container (the gpe_iconlist itself)
+  GtkWidget * iconlist;//top level container (scrolled_window containing the icon list)
   GtkWidget * textlist;//top level container (scrolled_window containing the list)
 
+  GtkWidget * iconlistview;
   GtkWidget * textlistview;
 
   GtkTreeModel * listmodel;
 
-  GtkWidget * button_edit;  //to set unsensitive
-  GtkWidget * button_delete;//to set unsensitive
+  GtkWidget * files_popup_button;
+
   GtkWidget * button_view;  //to switch the icon (from gpe-sketchbook.c)
+  GtkWidget * button_edit;
+  GtkWidget * button_delete;
 
   gboolean thumbnails_notloaded;
 } Selector;
 extern Selector selector;
 
 enum{//Entry id for the list store
-  ENTRY_TITLE = 0,
-  ENTRY_URL,
-  ENTRY_THUMBNAIL,
-  ENTRY_ICONLISTITEM,
+  ENTRY_TITLE        = 0,
+  ENTRY_ID           = 1,
+  ENTRY_CREATED_VAL  = 2,
+  ENTRY_CREATED      = 3,
+  ENTRY_UPDATED_VAL  = 4,
+  ENTRY_UPDATED      = 5,
+  ENTRY_URL          = 6,
+  ENTRY_THUMBNAIL    = 7,
+  ENTRY_ICONLISTITEM = 8,
   NUM_ENTRIES
 };
 
-void selector_add_note(gchar * title, gchar * url, GdkPixbuf * thumbnail);
+void selector_add_note(gint id,
+                       gchar * title,
+                       gchar * url,
+                       gint created,
+                       gint updated,
+                       GdkPixbuf * thumbnail);
 void load_thumbnails();
 
 extern gint sketch_list_size;
@@ -70,4 +83,6 @@ gchar * make_label_from_filename(const gchar * filename);
 void open_indexed_sketch(gint index);
 void delete_current_sketch();
 
+gchar * get_time_label(glong timestamp);
+
 #endif
